@@ -17,6 +17,7 @@ Usage::
         ListMembersPaginator,
         ListOrganizationAdminAccountsPaginator,
         Macie2Client,
+        SearchResourcesPaginator,
     )
 
     session = boto3.Session()
@@ -33,6 +34,7 @@ Usage::
     list_invitations_paginator: ListInvitationsPaginator = client.get_paginator("list_invitations")
     list_members_paginator: ListMembersPaginator = client.get_paginator("list_members")
     list_organization_admin_accounts_paginator: ListOrganizationAdminAccountsPaginator = client.get_paginator("list_organization_admin_accounts")
+    search_resources_paginator: SearchResourcesPaginator = client.get_paginator("search_resources")
     ```
 """
 from .client import Macie2Client
@@ -46,6 +48,7 @@ from .paginator import (
     ListInvitationsPaginator,
     ListMembersPaginator,
     ListOrganizationAdminAccountsPaginator,
+    SearchResourcesPaginator,
 )
 
 Client = Macie2Client
@@ -63,4 +66,5 @@ __all__ = (
     "ListMembersPaginator",
     "ListOrganizationAdminAccountsPaginator",
     "Macie2Client",
+    "SearchResourcesPaginator",
 )
