@@ -1,14 +1,14 @@
 """
 Type annotations for macie2 service type definitions.
 
-[Open documentation](./type_defs.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_macie2/type_defs.html)
 
 Usage::
 
     ```python
-    from mypy_boto3_macie2.type_defs import AccessControlListTypeDef
+    from mypy_boto3_macie2.type_defs import AcceptInvitationRequestRequestTypeDef
 
-    data: AccessControlListTypeDef = {...}
+    data: AcceptInvitationRequestRequestTypeDef = {...}
     ```
 """
 import sys
@@ -27,6 +27,7 @@ from .literals import (
     FindingsFilterActionType,
     FindingStatisticsSortAttributeNameType,
     FindingTypeType,
+    GroupByType,
     IsDefinedInJobType,
     IsMonitoredByJobType,
     JobComparatorType,
@@ -39,9 +40,13 @@ from .literals import (
     OrderByType,
     RelationshipStatusType,
     ScopeFilterKeyType,
+    SearchResourcesComparatorType,
+    SearchResourcesSimpleCriterionKeyType,
+    SearchResourcesSortAttributeNameType,
     SensitiveDataItemCategoryType,
     SeverityDescriptionType,
     SharedAccessType,
+    SimpleCriterionKeyForJobType,
     StorageClassType,
     TimeRangeType,
     TypeType,
@@ -63,6 +68,7 @@ else:
 
 
 __all__ = (
+    "AcceptInvitationRequestRequestTypeDef",
     "AccessControlListTypeDef",
     "AccountDetailTypeDef",
     "AccountLevelPermissionsTypeDef",
@@ -72,6 +78,7 @@ __all__ = (
     "AwsAccountTypeDef",
     "AwsServiceTypeDef",
     "BatchGetCustomDataIdentifierSummaryTypeDef",
+    "BatchGetCustomDataIdentifiersRequestRequestTypeDef",
     "BatchGetCustomDataIdentifiersResponseTypeDef",
     "BlockPublicAccessTypeDef",
     "BucketCountByEffectivePermissionTypeDef",
@@ -91,22 +98,41 @@ __all__ = (
     "ClassificationExportConfigurationTypeDef",
     "ClassificationResultStatusTypeDef",
     "ClassificationResultTypeDef",
+    "CreateClassificationJobRequestRequestTypeDef",
     "CreateClassificationJobResponseTypeDef",
+    "CreateCustomDataIdentifierRequestRequestTypeDef",
     "CreateCustomDataIdentifierResponseTypeDef",
+    "CreateFindingsFilterRequestRequestTypeDef",
     "CreateFindingsFilterResponseTypeDef",
+    "CreateInvitationsRequestRequestTypeDef",
     "CreateInvitationsResponseTypeDef",
+    "CreateMemberRequestRequestTypeDef",
     "CreateMemberResponseTypeDef",
+    "CreateSampleFindingsRequestRequestTypeDef",
+    "CriteriaBlockForJobTypeDef",
+    "CriteriaForJobTypeDef",
     "CriterionAdditionalPropertiesTypeDef",
     "CustomDataIdentifierSummaryTypeDef",
     "CustomDataIdentifiersTypeDef",
     "CustomDetectionTypeDef",
+    "DeclineInvitationsRequestRequestTypeDef",
     "DeclineInvitationsResponseTypeDef",
     "DefaultDetectionTypeDef",
+    "DeleteCustomDataIdentifierRequestRequestTypeDef",
+    "DeleteFindingsFilterRequestRequestTypeDef",
+    "DeleteInvitationsRequestRequestTypeDef",
     "DeleteInvitationsResponseTypeDef",
+    "DeleteMemberRequestRequestTypeDef",
+    "DescribeBucketsRequestRequestTypeDef",
     "DescribeBucketsResponseTypeDef",
+    "DescribeClassificationJobRequestRequestTypeDef",
     "DescribeClassificationJobResponseTypeDef",
     "DescribeOrganizationConfigurationResponseTypeDef",
+    "DisableOrganizationAdminAccountRequestRequestTypeDef",
+    "DisassociateMemberRequestRequestTypeDef",
     "DomainDetailsTypeDef",
+    "EnableMacieRequestRequestTypeDef",
+    "EnableOrganizationAdminAccountRequestRequestTypeDef",
     "FederatedUserTypeDef",
     "FindingActionTypeDef",
     "FindingActorTypeDef",
@@ -115,18 +141,26 @@ __all__ = (
     "FindingTypeDef",
     "FindingsFilterListItemTypeDef",
     "GetAdministratorAccountResponseTypeDef",
+    "GetBucketStatisticsRequestRequestTypeDef",
     "GetBucketStatisticsResponseTypeDef",
     "GetClassificationExportConfigurationResponseTypeDef",
+    "GetCustomDataIdentifierRequestRequestTypeDef",
     "GetCustomDataIdentifierResponseTypeDef",
+    "GetFindingStatisticsRequestRequestTypeDef",
     "GetFindingStatisticsResponseTypeDef",
+    "GetFindingsFilterRequestRequestTypeDef",
     "GetFindingsFilterResponseTypeDef",
     "GetFindingsPublicationConfigurationResponseTypeDef",
+    "GetFindingsRequestRequestTypeDef",
     "GetFindingsResponseTypeDef",
     "GetInvitationsCountResponseTypeDef",
     "GetMacieSessionResponseTypeDef",
     "GetMasterAccountResponseTypeDef",
+    "GetMemberRequestRequestTypeDef",
     "GetMemberResponseTypeDef",
+    "GetUsageStatisticsRequestRequestTypeDef",
     "GetUsageStatisticsResponseTypeDef",
+    "GetUsageTotalsRequestRequestTypeDef",
     "GetUsageTotalsResponseTypeDef",
     "GroupCountTypeDef",
     "IamUserTypeDef",
@@ -143,17 +177,27 @@ __all__ = (
     "JobSummaryTypeDef",
     "KeyValuePairTypeDef",
     "LastRunErrorStatusTypeDef",
+    "ListClassificationJobsRequestRequestTypeDef",
     "ListClassificationJobsResponseTypeDef",
+    "ListCustomDataIdentifiersRequestRequestTypeDef",
     "ListCustomDataIdentifiersResponseTypeDef",
+    "ListFindingsFiltersRequestRequestTypeDef",
     "ListFindingsFiltersResponseTypeDef",
+    "ListFindingsRequestRequestTypeDef",
     "ListFindingsResponseTypeDef",
+    "ListInvitationsRequestRequestTypeDef",
     "ListInvitationsResponseTypeDef",
     "ListJobsFilterCriteriaTypeDef",
     "ListJobsFilterTermTypeDef",
     "ListJobsSortCriteriaTypeDef",
+    "ListMembersRequestRequestTypeDef",
     "ListMembersResponseTypeDef",
+    "ListOrganizationAdminAccountsRequestRequestTypeDef",
     "ListOrganizationAdminAccountsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "MatchingBucketTypeDef",
+    "MatchingResourceTypeDef",
     "MemberTypeDef",
     "MonthlyScheduleTypeDef",
     "ObjectCountByEncryptionTypeTypeDef",
@@ -162,11 +206,15 @@ __all__ = (
     "PageTypeDef",
     "PaginatorConfigTypeDef",
     "PolicyDetailsTypeDef",
+    "PutClassificationExportConfigurationRequestRequestTypeDef",
     "PutClassificationExportConfigurationResponseTypeDef",
+    "PutFindingsPublicationConfigurationRequestRequestTypeDef",
     "RangeTypeDef",
     "RecordTypeDef",
     "ReplicationDetailsTypeDef",
     "ResourcesAffectedTypeDef",
+    "ResponseMetadataTypeDef",
+    "S3BucketCriteriaForJobTypeDef",
     "S3BucketDefinitionForJobTypeDef",
     "S3BucketOwnerTypeDef",
     "S3BucketTypeDef",
@@ -174,6 +222,15 @@ __all__ = (
     "S3JobDefinitionTypeDef",
     "S3ObjectTypeDef",
     "ScopingTypeDef",
+    "SearchResourcesBucketCriteriaTypeDef",
+    "SearchResourcesCriteriaBlockTypeDef",
+    "SearchResourcesCriteriaTypeDef",
+    "SearchResourcesRequestRequestTypeDef",
+    "SearchResourcesResponseTypeDef",
+    "SearchResourcesSimpleCriterionTypeDef",
+    "SearchResourcesSortCriteriaTypeDef",
+    "SearchResourcesTagCriterionPairTypeDef",
+    "SearchResourcesTagCriterionTypeDef",
     "SecurityHubConfigurationTypeDef",
     "SensitiveDataItemTypeDef",
     "ServerSideEncryptionTypeDef",
@@ -182,14 +239,25 @@ __all__ = (
     "SessionContextTypeDef",
     "SessionIssuerTypeDef",
     "SeverityTypeDef",
+    "SimpleCriterionForJobTypeDef",
     "SimpleScopeTermTypeDef",
     "SortCriteriaTypeDef",
     "StatisticsTypeDef",
+    "TagCriterionForJobTypeDef",
+    "TagCriterionPairForJobTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TagScopeTermTypeDef",
     "TagValuePairTypeDef",
+    "TestCustomDataIdentifierRequestRequestTypeDef",
     "TestCustomDataIdentifierResponseTypeDef",
     "UnprocessedAccountTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateClassificationJobRequestRequestTypeDef",
+    "UpdateFindingsFilterRequestRequestTypeDef",
     "UpdateFindingsFilterResponseTypeDef",
+    "UpdateMacieSessionRequestRequestTypeDef",
+    "UpdateMemberSessionRequestRequestTypeDef",
+    "UpdateOrganizationConfigurationRequestRequestTypeDef",
     "UsageByAccountTypeDef",
     "UsageRecordTypeDef",
     "UsageStatisticsFilterTypeDef",
@@ -201,6 +269,28 @@ __all__ = (
     "WeeklyScheduleTypeDef",
 )
 
+_RequiredAcceptInvitationRequestRequestTypeDef = TypedDict(
+    "_RequiredAcceptInvitationRequestRequestTypeDef",
+    {
+        "invitationId": str,
+    },
+)
+_OptionalAcceptInvitationRequestRequestTypeDef = TypedDict(
+    "_OptionalAcceptInvitationRequestRequestTypeDef",
+    {
+        "administratorAccountId": str,
+        "masterAccount": str,
+    },
+    total=False,
+)
+
+
+class AcceptInvitationRequestRequestTypeDef(
+    _RequiredAcceptInvitationRequestRequestTypeDef, _OptionalAcceptInvitationRequestRequestTypeDef
+):
+    pass
+
+
 AccessControlListTypeDef = TypedDict(
     "AccessControlListTypeDef",
     {
@@ -288,13 +378,21 @@ BatchGetCustomDataIdentifierSummaryTypeDef = TypedDict(
     total=False,
 )
 
+BatchGetCustomDataIdentifiersRequestRequestTypeDef = TypedDict(
+    "BatchGetCustomDataIdentifiersRequestRequestTypeDef",
+    {
+        "ids": List[str],
+    },
+    total=False,
+)
+
 BatchGetCustomDataIdentifiersResponseTypeDef = TypedDict(
     "BatchGetCustomDataIdentifiersResponseTypeDef",
     {
         "customDataIdentifiers": List["BatchGetCustomDataIdentifierSummaryTypeDef"],
         "notFoundIdentifierIds": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 BlockPublicAccessTypeDef = TypedDict(
@@ -501,11 +599,56 @@ ClassificationResultTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredCreateClassificationJobRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateClassificationJobRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "jobType": JobTypeType,
+        "name": str,
+        "s3JobDefinition": "S3JobDefinitionTypeDef",
+    },
+)
+_OptionalCreateClassificationJobRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateClassificationJobRequestRequestTypeDef",
+    {
+        "customDataIdentifierIds": List[str],
+        "description": str,
+        "initialRun": bool,
+        "samplingPercentage": int,
+        "scheduleFrequency": "JobScheduleFrequencyTypeDef",
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class CreateClassificationJobRequestRequestTypeDef(
+    _RequiredCreateClassificationJobRequestRequestTypeDef,
+    _OptionalCreateClassificationJobRequestRequestTypeDef,
+):
+    pass
+
+
 CreateClassificationJobResponseTypeDef = TypedDict(
     "CreateClassificationJobResponseTypeDef",
     {
         "jobArn": str,
         "jobId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+CreateCustomDataIdentifierRequestRequestTypeDef = TypedDict(
+    "CreateCustomDataIdentifierRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "description": str,
+        "ignoreWords": List[str],
+        "keywords": List[str],
+        "maximumMatchDistance": int,
+        "name": str,
+        "regex": str,
+        "tags": Dict[str, str],
     },
     total=False,
 )
@@ -514,31 +657,126 @@ CreateCustomDataIdentifierResponseTypeDef = TypedDict(
     "CreateCustomDataIdentifierResponseTypeDef",
     {
         "customDataIdentifierId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateFindingsFilterRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateFindingsFilterRequestRequestTypeDef",
+    {
+        "action": FindingsFilterActionType,
+        "findingCriteria": "FindingCriteriaTypeDef",
+        "name": str,
+    },
+)
+_OptionalCreateFindingsFilterRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateFindingsFilterRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "description": str,
+        "position": int,
+        "tags": Dict[str, str],
     },
     total=False,
 )
 
+
+class CreateFindingsFilterRequestRequestTypeDef(
+    _RequiredCreateFindingsFilterRequestRequestTypeDef,
+    _OptionalCreateFindingsFilterRequestRequestTypeDef,
+):
+    pass
+
+
 CreateFindingsFilterResponseTypeDef = TypedDict(
     "CreateFindingsFilterResponseTypeDef",
     {
         "arn": str,
         "id": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateInvitationsRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateInvitationsRequestRequestTypeDef",
+    {
+        "accountIds": List[str],
+    },
+)
+_OptionalCreateInvitationsRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateInvitationsRequestRequestTypeDef",
+    {
+        "disableEmailNotification": bool,
+        "message": str,
     },
     total=False,
 )
 
+
+class CreateInvitationsRequestRequestTypeDef(
+    _RequiredCreateInvitationsRequestRequestTypeDef, _OptionalCreateInvitationsRequestRequestTypeDef
+):
+    pass
+
+
 CreateInvitationsResponseTypeDef = TypedDict(
     "CreateInvitationsResponseTypeDef",
     {
         "unprocessedAccounts": List["UnprocessedAccountTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateMemberRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateMemberRequestRequestTypeDef",
+    {
+        "account": "AccountDetailTypeDef",
+    },
+)
+_OptionalCreateMemberRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateMemberRequestRequestTypeDef",
+    {
+        "tags": Dict[str, str],
     },
     total=False,
 )
 
+
+class CreateMemberRequestRequestTypeDef(
+    _RequiredCreateMemberRequestRequestTypeDef, _OptionalCreateMemberRequestRequestTypeDef
+):
+    pass
+
+
 CreateMemberResponseTypeDef = TypedDict(
     "CreateMemberResponseTypeDef",
     {
         "arn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+CreateSampleFindingsRequestRequestTypeDef = TypedDict(
+    "CreateSampleFindingsRequestRequestTypeDef",
+    {
+        "findingTypes": List[FindingTypeType],
+    },
+    total=False,
+)
+
+CriteriaBlockForJobTypeDef = TypedDict(
+    "CriteriaBlockForJobTypeDef",
+    {
+        "and": List["CriteriaForJobTypeDef"],
+    },
+    total=False,
+)
+
+CriteriaForJobTypeDef = TypedDict(
+    "CriteriaForJobTypeDef",
+    {
+        "simpleCriterion": "SimpleCriterionForJobTypeDef",
+        "tagCriterion": "TagCriterionForJobTypeDef",
     },
     total=False,
 )
@@ -589,12 +827,19 @@ CustomDetectionTypeDef = TypedDict(
     total=False,
 )
 
+DeclineInvitationsRequestRequestTypeDef = TypedDict(
+    "DeclineInvitationsRequestRequestTypeDef",
+    {
+        "accountIds": List[str],
+    },
+)
+
 DeclineInvitationsResponseTypeDef = TypedDict(
     "DeclineInvitationsResponseTypeDef",
     {
         "unprocessedAccounts": List["UnprocessedAccountTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 DefaultDetectionTypeDef = TypedDict(
@@ -607,10 +852,49 @@ DefaultDetectionTypeDef = TypedDict(
     total=False,
 )
 
+DeleteCustomDataIdentifierRequestRequestTypeDef = TypedDict(
+    "DeleteCustomDataIdentifierRequestRequestTypeDef",
+    {
+        "id": str,
+    },
+)
+
+DeleteFindingsFilterRequestRequestTypeDef = TypedDict(
+    "DeleteFindingsFilterRequestRequestTypeDef",
+    {
+        "id": str,
+    },
+)
+
+DeleteInvitationsRequestRequestTypeDef = TypedDict(
+    "DeleteInvitationsRequestRequestTypeDef",
+    {
+        "accountIds": List[str],
+    },
+)
+
 DeleteInvitationsResponseTypeDef = TypedDict(
     "DeleteInvitationsResponseTypeDef",
     {
         "unprocessedAccounts": List["UnprocessedAccountTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DeleteMemberRequestRequestTypeDef = TypedDict(
+    "DeleteMemberRequestRequestTypeDef",
+    {
+        "id": str,
+    },
+)
+
+DescribeBucketsRequestRequestTypeDef = TypedDict(
+    "DescribeBucketsRequestRequestTypeDef",
+    {
+        "criteria": Dict[str, "BucketCriteriaAdditionalPropertiesTypeDef"],
+        "maxResults": int,
+        "nextToken": str,
+        "sortCriteria": "BucketSortCriteriaTypeDef",
     },
     total=False,
 )
@@ -620,8 +904,15 @@ DescribeBucketsResponseTypeDef = TypedDict(
     {
         "buckets": List["BucketMetadataTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeClassificationJobRequestRequestTypeDef = TypedDict(
+    "DescribeClassificationJobRequestRequestTypeDef",
+    {
+        "jobId": str,
     },
-    total=False,
 )
 
 DescribeClassificationJobResponseTypeDef = TypedDict(
@@ -645,8 +936,8 @@ DescribeClassificationJobResponseTypeDef = TypedDict(
         "statistics": "StatisticsTypeDef",
         "tags": Dict[str, str],
         "userPausedDetails": "UserPausedDetailsTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 DescribeOrganizationConfigurationResponseTypeDef = TypedDict(
@@ -654,8 +945,22 @@ DescribeOrganizationConfigurationResponseTypeDef = TypedDict(
     {
         "autoEnable": bool,
         "maxAccountLimitReached": bool,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DisableOrganizationAdminAccountRequestRequestTypeDef = TypedDict(
+    "DisableOrganizationAdminAccountRequestRequestTypeDef",
+    {
+        "adminAccountId": str,
+    },
+)
+
+DisassociateMemberRequestRequestTypeDef = TypedDict(
+    "DisassociateMemberRequestRequestTypeDef",
+    {
+        "id": str,
     },
-    total=False,
 )
 
 DomainDetailsTypeDef = TypedDict(
@@ -666,6 +971,38 @@ DomainDetailsTypeDef = TypedDict(
     total=False,
 )
 
+EnableMacieRequestRequestTypeDef = TypedDict(
+    "EnableMacieRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "findingPublishingFrequency": FindingPublishingFrequencyType,
+        "status": MacieStatusType,
+    },
+    total=False,
+)
+
+_RequiredEnableOrganizationAdminAccountRequestRequestTypeDef = TypedDict(
+    "_RequiredEnableOrganizationAdminAccountRequestRequestTypeDef",
+    {
+        "adminAccountId": str,
+    },
+)
+_OptionalEnableOrganizationAdminAccountRequestRequestTypeDef = TypedDict(
+    "_OptionalEnableOrganizationAdminAccountRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class EnableOrganizationAdminAccountRequestRequestTypeDef(
+    _RequiredEnableOrganizationAdminAccountRequestRequestTypeDef,
+    _OptionalEnableOrganizationAdminAccountRequestRequestTypeDef,
+):
+    pass
+
+
 FederatedUserTypeDef = TypedDict(
     "FederatedUserTypeDef",
     {
@@ -755,6 +1092,14 @@ GetAdministratorAccountResponseTypeDef = TypedDict(
     "GetAdministratorAccountResponseTypeDef",
     {
         "administrator": "InvitationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetBucketStatisticsRequestRequestTypeDef = TypedDict(
+    "GetBucketStatisticsRequestRequestTypeDef",
+    {
+        "accountId": str,
     },
     total=False,
 )
@@ -775,16 +1120,23 @@ GetBucketStatisticsResponseTypeDef = TypedDict(
         "sizeInBytesCompressed": int,
         "unclassifiableObjectCount": "ObjectLevelStatisticsTypeDef",
         "unclassifiableObjectSizeInBytes": "ObjectLevelStatisticsTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 GetClassificationExportConfigurationResponseTypeDef = TypedDict(
     "GetClassificationExportConfigurationResponseTypeDef",
     {
         "configuration": "ClassificationExportConfigurationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetCustomDataIdentifierRequestRequestTypeDef = TypedDict(
+    "GetCustomDataIdentifierRequestRequestTypeDef",
+    {
+        "id": str,
     },
-    total=False,
 )
 
 GetCustomDataIdentifierResponseTypeDef = TypedDict(
@@ -801,16 +1153,47 @@ GetCustomDataIdentifierResponseTypeDef = TypedDict(
         "name": str,
         "regex": str,
         "tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetFindingStatisticsRequestRequestTypeDef = TypedDict(
+    "_RequiredGetFindingStatisticsRequestRequestTypeDef",
+    {
+        "groupBy": GroupByType,
+    },
+)
+_OptionalGetFindingStatisticsRequestRequestTypeDef = TypedDict(
+    "_OptionalGetFindingStatisticsRequestRequestTypeDef",
+    {
+        "findingCriteria": "FindingCriteriaTypeDef",
+        "size": int,
+        "sortCriteria": "FindingStatisticsSortCriteriaTypeDef",
     },
     total=False,
 )
 
+
+class GetFindingStatisticsRequestRequestTypeDef(
+    _RequiredGetFindingStatisticsRequestRequestTypeDef,
+    _OptionalGetFindingStatisticsRequestRequestTypeDef,
+):
+    pass
+
+
 GetFindingStatisticsResponseTypeDef = TypedDict(
     "GetFindingStatisticsResponseTypeDef",
     {
         "countsByGroup": List["GroupCountTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetFindingsFilterRequestRequestTypeDef = TypedDict(
+    "GetFindingsFilterRequestRequestTypeDef",
+    {
+        "id": str,
     },
-    total=False,
 )
 
 GetFindingsFilterResponseTypeDef = TypedDict(
@@ -824,32 +1207,53 @@ GetFindingsFilterResponseTypeDef = TypedDict(
         "name": str,
         "position": int,
         "tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 GetFindingsPublicationConfigurationResponseTypeDef = TypedDict(
     "GetFindingsPublicationConfigurationResponseTypeDef",
     {
         "securityHubConfiguration": "SecurityHubConfigurationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetFindingsRequestRequestTypeDef = TypedDict(
+    "_RequiredGetFindingsRequestRequestTypeDef",
+    {
+        "findingIds": List[str],
+    },
+)
+_OptionalGetFindingsRequestRequestTypeDef = TypedDict(
+    "_OptionalGetFindingsRequestRequestTypeDef",
+    {
+        "sortCriteria": "SortCriteriaTypeDef",
     },
     total=False,
 )
 
+
+class GetFindingsRequestRequestTypeDef(
+    _RequiredGetFindingsRequestRequestTypeDef, _OptionalGetFindingsRequestRequestTypeDef
+):
+    pass
+
+
 GetFindingsResponseTypeDef = TypedDict(
     "GetFindingsResponseTypeDef",
     {
         "findings": List["FindingTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 GetInvitationsCountResponseTypeDef = TypedDict(
     "GetInvitationsCountResponseTypeDef",
     {
         "invitationsCount": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 GetMacieSessionResponseTypeDef = TypedDict(
@@ -860,16 +1264,23 @@ GetMacieSessionResponseTypeDef = TypedDict(
         "serviceRole": str,
         "status": MacieStatusType,
         "updatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 GetMasterAccountResponseTypeDef = TypedDict(
     "GetMasterAccountResponseTypeDef",
     {
         "master": "InvitationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetMemberRequestRequestTypeDef = TypedDict(
+    "GetMemberRequestRequestTypeDef",
+    {
+        "id": str,
     },
-    total=False,
 )
 
 GetMemberResponseTypeDef = TypedDict(
@@ -884,6 +1295,18 @@ GetMemberResponseTypeDef = TypedDict(
         "relationshipStatus": RelationshipStatusType,
         "tags": Dict[str, str],
         "updatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetUsageStatisticsRequestRequestTypeDef = TypedDict(
+    "GetUsageStatisticsRequestRequestTypeDef",
+    {
+        "filterBy": List["UsageStatisticsFilterTypeDef"],
+        "maxResults": int,
+        "nextToken": str,
+        "sortBy": "UsageStatisticsSortByTypeDef",
+        "timeRange": TimeRangeType,
     },
     total=False,
 )
@@ -894,6 +1317,14 @@ GetUsageStatisticsResponseTypeDef = TypedDict(
         "nextToken": str,
         "records": List["UsageRecordTypeDef"],
         "timeRange": TimeRangeType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetUsageTotalsRequestRequestTypeDef = TypedDict(
+    "GetUsageTotalsRequestRequestTypeDef",
+    {
+        "timeRange": str,
     },
     total=False,
 )
@@ -903,8 +1334,8 @@ GetUsageTotalsResponseTypeDef = TypedDict(
     {
         "timeRange": TimeRangeType,
         "usageTotals": List["UsageTotalTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 GroupCountTypeDef = TypedDict(
@@ -1036,6 +1467,7 @@ JobSummaryTypeDef = TypedDict(
         "lastRunErrorStatus": "LastRunErrorStatusTypeDef",
         "name": str,
         "userPausedDetails": "UserPausedDetailsTypeDef",
+        "bucketCriteria": "S3BucketCriteriaForJobTypeDef",
     },
     total=False,
 )
@@ -1057,11 +1489,31 @@ LastRunErrorStatusTypeDef = TypedDict(
     total=False,
 )
 
+ListClassificationJobsRequestRequestTypeDef = TypedDict(
+    "ListClassificationJobsRequestRequestTypeDef",
+    {
+        "filterCriteria": "ListJobsFilterCriteriaTypeDef",
+        "maxResults": int,
+        "nextToken": str,
+        "sortCriteria": "ListJobsSortCriteriaTypeDef",
+    },
+    total=False,
+)
+
 ListClassificationJobsResponseTypeDef = TypedDict(
     "ListClassificationJobsResponseTypeDef",
     {
         "items": List["JobSummaryTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListCustomDataIdentifiersRequestRequestTypeDef = TypedDict(
+    "ListCustomDataIdentifiersRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
     },
     total=False,
 )
@@ -1071,6 +1523,15 @@ ListCustomDataIdentifiersResponseTypeDef = TypedDict(
     {
         "items": List["CustomDataIdentifierSummaryTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListFindingsFiltersRequestRequestTypeDef = TypedDict(
+    "ListFindingsFiltersRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
     },
     total=False,
 )
@@ -1080,6 +1541,17 @@ ListFindingsFiltersResponseTypeDef = TypedDict(
     {
         "findingsFilterListItems": List["FindingsFilterListItemTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListFindingsRequestRequestTypeDef = TypedDict(
+    "ListFindingsRequestRequestTypeDef",
+    {
+        "findingCriteria": "FindingCriteriaTypeDef",
+        "maxResults": int,
+        "nextToken": str,
+        "sortCriteria": "SortCriteriaTypeDef",
     },
     total=False,
 )
@@ -1089,6 +1561,15 @@ ListFindingsResponseTypeDef = TypedDict(
     {
         "findingIds": List[str],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListInvitationsRequestRequestTypeDef = TypedDict(
+    "ListInvitationsRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
     },
     total=False,
 )
@@ -1098,8 +1579,8 @@ ListInvitationsResponseTypeDef = TypedDict(
     {
         "invitations": List["InvitationTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ListJobsFilterCriteriaTypeDef = TypedDict(
@@ -1130,11 +1611,30 @@ ListJobsSortCriteriaTypeDef = TypedDict(
     total=False,
 )
 
+ListMembersRequestRequestTypeDef = TypedDict(
+    "ListMembersRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+        "onlyAssociated": str,
+    },
+    total=False,
+)
+
 ListMembersResponseTypeDef = TypedDict(
     "ListMembersResponseTypeDef",
     {
         "members": List["MemberTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListOrganizationAdminAccountsRequestRequestTypeDef = TypedDict(
+    "ListOrganizationAdminAccountsRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
     },
     total=False,
 )
@@ -1144,14 +1644,47 @@ ListOrganizationAdminAccountsResponseTypeDef = TypedDict(
     {
         "adminAccounts": List["AdminAccountTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
     },
-    total=False,
 )
 
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
     {
         "tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+MatchingBucketTypeDef = TypedDict(
+    "MatchingBucketTypeDef",
+    {
+        "accountId": str,
+        "bucketName": str,
+        "classifiableObjectCount": int,
+        "classifiableSizeInBytes": int,
+        "jobDetails": "JobDetailsTypeDef",
+        "objectCount": int,
+        "objectCountByEncryptionType": "ObjectCountByEncryptionTypeTypeDef",
+        "sizeInBytes": int,
+        "sizeInBytesCompressed": int,
+        "unclassifiableObjectCount": "ObjectLevelStatisticsTypeDef",
+        "unclassifiableObjectSizeInBytes": "ObjectLevelStatisticsTypeDef",
+    },
+    total=False,
+)
+
+MatchingResourceTypeDef = TypedDict(
+    "MatchingResourceTypeDef",
+    {
+        "matchingBucket": "MatchingBucketTypeDef",
     },
     total=False,
 )
@@ -1243,10 +1776,26 @@ PolicyDetailsTypeDef = TypedDict(
     total=False,
 )
 
+PutClassificationExportConfigurationRequestRequestTypeDef = TypedDict(
+    "PutClassificationExportConfigurationRequestRequestTypeDef",
+    {
+        "configuration": "ClassificationExportConfigurationTypeDef",
+    },
+)
+
 PutClassificationExportConfigurationResponseTypeDef = TypedDict(
     "PutClassificationExportConfigurationResponseTypeDef",
     {
         "configuration": "ClassificationExportConfigurationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+PutFindingsPublicationConfigurationRequestRequestTypeDef = TypedDict(
+    "PutFindingsPublicationConfigurationRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "securityHubConfiguration": "SecurityHubConfigurationTypeDef",
     },
     total=False,
 )
@@ -1289,6 +1838,26 @@ ResourcesAffectedTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
+S3BucketCriteriaForJobTypeDef = TypedDict(
+    "S3BucketCriteriaForJobTypeDef",
+    {
+        "excludes": "CriteriaBlockForJobTypeDef",
+        "includes": "CriteriaBlockForJobTypeDef",
+    },
+    total=False,
+)
+
 S3BucketDefinitionForJobTypeDef = TypedDict(
     "S3BucketDefinitionForJobTypeDef",
     {
@@ -1346,6 +1915,7 @@ S3JobDefinitionTypeDef = TypedDict(
     {
         "bucketDefinitions": List["S3BucketDefinitionForJobTypeDef"],
         "scoping": "ScopingTypeDef",
+        "bucketCriteria": "S3BucketCriteriaForJobTypeDef",
     },
     total=False,
 )
@@ -1378,6 +1948,89 @@ ScopingTypeDef = TypedDict(
     total=False,
 )
 
+SearchResourcesBucketCriteriaTypeDef = TypedDict(
+    "SearchResourcesBucketCriteriaTypeDef",
+    {
+        "excludes": "SearchResourcesCriteriaBlockTypeDef",
+        "includes": "SearchResourcesCriteriaBlockTypeDef",
+    },
+    total=False,
+)
+
+SearchResourcesCriteriaBlockTypeDef = TypedDict(
+    "SearchResourcesCriteriaBlockTypeDef",
+    {
+        "and": List["SearchResourcesCriteriaTypeDef"],
+    },
+    total=False,
+)
+
+SearchResourcesCriteriaTypeDef = TypedDict(
+    "SearchResourcesCriteriaTypeDef",
+    {
+        "simpleCriterion": "SearchResourcesSimpleCriterionTypeDef",
+        "tagCriterion": "SearchResourcesTagCriterionTypeDef",
+    },
+    total=False,
+)
+
+SearchResourcesRequestRequestTypeDef = TypedDict(
+    "SearchResourcesRequestRequestTypeDef",
+    {
+        "bucketCriteria": "SearchResourcesBucketCriteriaTypeDef",
+        "maxResults": int,
+        "nextToken": str,
+        "sortCriteria": "SearchResourcesSortCriteriaTypeDef",
+    },
+    total=False,
+)
+
+SearchResourcesResponseTypeDef = TypedDict(
+    "SearchResourcesResponseTypeDef",
+    {
+        "matchingResources": List["MatchingResourceTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+SearchResourcesSimpleCriterionTypeDef = TypedDict(
+    "SearchResourcesSimpleCriterionTypeDef",
+    {
+        "comparator": SearchResourcesComparatorType,
+        "key": SearchResourcesSimpleCriterionKeyType,
+        "values": List[str],
+    },
+    total=False,
+)
+
+SearchResourcesSortCriteriaTypeDef = TypedDict(
+    "SearchResourcesSortCriteriaTypeDef",
+    {
+        "attributeName": SearchResourcesSortAttributeNameType,
+        "orderBy": OrderByType,
+    },
+    total=False,
+)
+
+SearchResourcesTagCriterionPairTypeDef = TypedDict(
+    "SearchResourcesTagCriterionPairTypeDef",
+    {
+        "key": str,
+        "value": str,
+    },
+    total=False,
+)
+
+SearchResourcesTagCriterionTypeDef = TypedDict(
+    "SearchResourcesTagCriterionTypeDef",
+    {
+        "comparator": SearchResourcesComparatorType,
+        "tagValues": List["SearchResourcesTagCriterionPairTypeDef"],
+    },
+    total=False,
+)
+
 SecurityHubConfigurationTypeDef = TypedDict(
     "SecurityHubConfigurationTypeDef",
     {
@@ -1454,6 +2107,16 @@ SeverityTypeDef = TypedDict(
     total=False,
 )
 
+SimpleCriterionForJobTypeDef = TypedDict(
+    "SimpleCriterionForJobTypeDef",
+    {
+        "comparator": JobComparatorType,
+        "key": SimpleCriterionKeyForJobType,
+        "values": List[str],
+    },
+    total=False,
+)
+
 SimpleScopeTermTypeDef = TypedDict(
     "SimpleScopeTermTypeDef",
     {
@@ -1482,6 +2145,32 @@ StatisticsTypeDef = TypedDict(
     total=False,
 )
 
+TagCriterionForJobTypeDef = TypedDict(
+    "TagCriterionForJobTypeDef",
+    {
+        "comparator": JobComparatorType,
+        "tagValues": List["TagCriterionPairForJobTypeDef"],
+    },
+    total=False,
+)
+
+TagCriterionPairForJobTypeDef = TypedDict(
+    "TagCriterionPairForJobTypeDef",
+    {
+        "key": str,
+        "value": str,
+    },
+    total=False,
+)
+
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tags": Dict[str, str],
+    },
+)
+
 TagScopeTermTypeDef = TypedDict(
     "TagScopeTermTypeDef",
     {
@@ -1502,12 +2191,37 @@ TagValuePairTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredTestCustomDataIdentifierRequestRequestTypeDef = TypedDict(
+    "_RequiredTestCustomDataIdentifierRequestRequestTypeDef",
+    {
+        "regex": str,
+        "sampleText": str,
+    },
+)
+_OptionalTestCustomDataIdentifierRequestRequestTypeDef = TypedDict(
+    "_OptionalTestCustomDataIdentifierRequestRequestTypeDef",
+    {
+        "ignoreWords": List[str],
+        "keywords": List[str],
+        "maximumMatchDistance": int,
+    },
+    total=False,
+)
+
+
+class TestCustomDataIdentifierRequestRequestTypeDef(
+    _RequiredTestCustomDataIdentifierRequestRequestTypeDef,
+    _OptionalTestCustomDataIdentifierRequestRequestTypeDef,
+):
+    pass
+
+
 TestCustomDataIdentifierResponseTypeDef = TypedDict(
     "TestCustomDataIdentifierResponseTypeDef",
     {
         "matchCount": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 UnprocessedAccountTypeDef = TypedDict(
@@ -1520,15 +2234,82 @@ UnprocessedAccountTypeDef = TypedDict(
     total=False,
 )
 
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tagKeys": List[str],
+    },
+)
+
+UpdateClassificationJobRequestRequestTypeDef = TypedDict(
+    "UpdateClassificationJobRequestRequestTypeDef",
+    {
+        "jobId": str,
+        "jobStatus": JobStatusType,
+    },
+)
+
+_RequiredUpdateFindingsFilterRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateFindingsFilterRequestRequestTypeDef",
+    {
+        "id": str,
+    },
+)
+_OptionalUpdateFindingsFilterRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateFindingsFilterRequestRequestTypeDef",
+    {
+        "action": FindingsFilterActionType,
+        "description": str,
+        "findingCriteria": "FindingCriteriaTypeDef",
+        "name": str,
+        "position": int,
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class UpdateFindingsFilterRequestRequestTypeDef(
+    _RequiredUpdateFindingsFilterRequestRequestTypeDef,
+    _OptionalUpdateFindingsFilterRequestRequestTypeDef,
+):
+    pass
+
+
 UpdateFindingsFilterResponseTypeDef = TypedDict(
     "UpdateFindingsFilterResponseTypeDef",
     {
         "arn": str,
         "id": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+UpdateMacieSessionRequestRequestTypeDef = TypedDict(
+    "UpdateMacieSessionRequestRequestTypeDef",
+    {
+        "findingPublishingFrequency": FindingPublishingFrequencyType,
+        "status": MacieStatusType,
     },
     total=False,
 )
 
+UpdateMemberSessionRequestRequestTypeDef = TypedDict(
+    "UpdateMemberSessionRequestRequestTypeDef",
+    {
+        "id": str,
+        "status": MacieStatusType,
+    },
+)
+
+UpdateOrganizationConfigurationRequestRequestTypeDef = TypedDict(
+    "UpdateOrganizationConfigurationRequestRequestTypeDef",
+    {
+        "autoEnable": bool,
+    },
+)
+
 UsageByAccountTypeDef = TypedDict(
     "UsageByAccountTypeDef",
     {
